@@ -158,7 +158,8 @@ class ZoneName {
         "America/Cayenne", "French_Guiana", "America/Cayenne",
         "America/Cayman", "America_Eastern", "America/New_York",
         "America/Chicago", "America_Central", "America/Chicago",
-        "America/Chihuahua", "Mexico_Pacific", "America/Mazatlan",
+        "America/Chihuahua", "America_Central", "America/Chicago",
+        "America/Ciudad_Juarez", "America_Mountain", "America/Denver",
         "America/Coral_Harbour", "America_Eastern", "America/New_York",
         "America/Cordoba", "Argentina", "America/Buenos_Aires",
         "America/Costa_Rica", "America_Central", "America/Chicago",
@@ -238,7 +239,7 @@ class ZoneName {
         "America/North_Dakota/Beulah", "America_Central", "America/Chicago",
         "America/North_Dakota/Center", "America_Central", "America/Chicago",
         "America/North_Dakota/New_Salem", "America_Central", "America/Chicago",
-        "America/Ojinaga", "America_Mountain", "America/Denver",
+        "America/Ojinaga", "America_Central", "America/Chicago",
         "America/Panama", "America_Eastern", "America/New_York",
         "America/Pangnirtung", "America_Eastern", "America/New_York",
         "America/Paramaribo", "Suriname", "America/Paramaribo",
@@ -469,6 +470,7 @@ class ZoneName {
         "Europe/Jersey", "GMT", "Atlantic/Reykjavik",
         "Europe/Kaliningrad", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Kiev", "Europe_Eastern", "Europe/Bucharest",
+        "Europe/Kyiv", "Europe_Eastern", "Europe/Bucharest",
         "Europe/Lisbon", "Europe_Western", "Atlantic/Canary",
         "Europe/Ljubljana", "Europe_Central", "Europe/Paris",
         "Europe/London", "GMT", "Atlantic/Reykjavik",
@@ -597,7 +599,6 @@ class ZoneName {
         "US/Michigan", "America_Eastern", "America/New_York",
         "US/Mountain", "America_Mountain", "America/Denver",
         "US/Pacific", "America_Pacific", "America/Los_Angeles",
-        "US/Pacific-New", "America_Pacific", "America/Los_Angeles",
         "US/Samoa", "Samoa", "Pacific/Pago_Pago",
         "W-SU", "Moscow", "Europe/Moscow",
 
@@ -841,8 +842,11 @@ class ZoneName {
         "America/Montreal", "America/Toronto",
         "America/Montserrat", "America/Puerto_Rico",
         "America/Nassau", "America/Toronto",
+        "America/Nipigon", "America/Toronto",
+        "America/Pangnirtung", "America/Iqaluit",
         "America/Port_of_Spain", "America/Puerto_Rico",
         "America/Porto_Acre", "America/Rio_Branco",
+        "America/Rainy_River", "America/Winnipeg",
         "America/Rosario", "America/Argentina/Cordoba",
         "America/Santa_Isabel", "America/Tijuana",
         "America/Shiprock", "America/Denver",
@@ -851,16 +855,19 @@ class ZoneName {
         "America/St_Lucia", "America/Puerto_Rico",
         "America/St_Thomas", "America/Puerto_Rico",
         "America/St_Vincent", "America/Puerto_Rico",
+        "America/Thunder_Bay", "America/Toronto",
         "America/Tortola", "America/Puerto_Rico",
         "America/Virgin", "America/Puerto_Rico",
+        "America/Yellowknife", "America/Edmonton",
         "Antarctica/DumontDUrville", "Pacific/Port_Moresby",
         "Antarctica/McMurdo", "Pacific/Auckland",
         "Antarctica/South_Pole", "Pacific/Auckland",
         "Antarctica/Syowa", "Asia/Riyadh",
-        "Arctic/Longyearbyen", "Europe/Oslo",
+        "Arctic/Longyearbyen", "Europe/Berlin",
         "Asia/Aden", "Asia/Riyadh",
         "Asia/Ashkhabad", "Asia/Ashgabat",
         "Asia/Bahrain", "Asia/Qatar",
+        "Asia/Brunei", "Asia/Kuching",
         "Asia/Calcutta", "Asia/Kolkata",
         "Asia/Chongqing", "Asia/Shanghai",
         "Asia/Chungking", "Asia/Shanghai",
@@ -869,6 +876,7 @@ class ZoneName {
         "Asia/Istanbul", "Europe/Istanbul",
         "Asia/Kashgar", "Asia/Urumqi",
         "Asia/Katmandu", "Asia/Kathmandu",
+        "Asia/Kuala_Lumpur", "Asia/Singapore",
         "Asia/Kuwait", "Asia/Riyadh",
         "Asia/Macao", "Asia/Macau",
         "Asia/Muscat", "Asia/Dubai",
@@ -881,7 +889,8 @@ class ZoneName {
         "Asia/Ulan_Bator", "Asia/Ulaanbaatar",
         "Asia/Vientiane", "Asia/Bangkok",
         "Atlantic/Faeroe", "Atlantic/Faroe",
-        "Atlantic/Jan_Mayen", "Europe/Oslo",
+        "Atlantic/Jan_Mayen", "Europe/Berlin",
+        "Atlantic/Reykjavik", "Africa/Abidjan",
         "Atlantic/St_Helena", "Africa/Abidjan",
         "Australia/ACT", "Australia/Sydney",
         "Australia/Canberra", "Australia/Sydney",
@@ -919,23 +928,32 @@ class ZoneName {
         "Etc/UCT", "Etc/UTC",
         "Etc/Universal", "Etc/UTC",
         "Etc/Zulu", "Etc/UTC",
+        "Europe/Amsterdam", "Europe/Brussels",
         "Europe/Belfast", "Europe/London",
         "Europe/Bratislava", "Europe/Prague",
         "Europe/Busingen", "Europe/Zurich",
+        "Europe/Copenhagen", "Europe/Berlin",
         "Europe/Guernsey", "Europe/London",
         "Europe/Isle_of_Man", "Europe/London",
         "Europe/Jersey", "Europe/London",
+        "Europe/Kiev", "Europe/Kyiv",
         "Europe/Ljubljana", "Europe/Belgrade",
+        "Europe/Luxembourg", "Europe/Brussels",
         "Europe/Mariehamn", "Europe/Helsinki",
+        "Europe/Monaco", "Europe/Paris",
         "Europe/Nicosia", "Asia/Nicosia",
+        "Europe/Oslo", "Europe/Berlin",
         "Europe/Podgorica", "Europe/Belgrade",
         "Europe/San_Marino", "Europe/Rome",
         "Europe/Sarajevo", "Europe/Belgrade",
         "Europe/Skopje", "Europe/Belgrade",
+        "Europe/Stockholm", "Europe/Berlin",
         "Europe/Tiraspol", "Europe/Chisinau",
+        "Europe/Uzhgorod", "Europe/Kyiv",
         "Europe/Vaduz", "Europe/Zurich",
         "Europe/Vatican", "Europe/Rome",
         "Europe/Zagreb", "Europe/Belgrade",
+        "Europe/Zaporozhye", "Europe/Kyiv",
         "GB", "Europe/London",
         "GB-Eire", "Europe/London",
         "GMT", "Etc/GMT",
@@ -944,10 +962,15 @@ class ZoneName {
         "GMT0", "Etc/GMT",
         "Greenwich", "Etc/GMT",
         "Hongkong", "Asia/Hong_Kong",
-        "Iceland", "Atlantic/Reykjavik",
+        "Iceland", "Africa/Abidjan",
         "Indian/Antananarivo", "Africa/Nairobi",
+        "Indian/Christmas", "Asia/Bangkok",
+        "Indian/Cocos", "Asia/Yangon",
         "Indian/Comoro", "Africa/Nairobi",
+        "Indian/Kerguelen", "Indian/Maldives",
+        "Indian/Mahe", "Asia/Dubai",
         "Indian/Mayotte", "Africa/Nairobi",
+        "Indian/Reunion", "Asia/Dubai",
         "Iran", "Asia/Tehran",
         "Israel", "Asia/Jerusalem",
         "Jamaica", "America/Jamaica",
@@ -964,14 +987,20 @@ class ZoneName {
         "NZ-CHAT", "Pacific/Chatham",
         "Navajo", "America/Denver",
         "PRC", "Asia/Shanghai",
+        "Pacific/Chuuk", "Pacific/Port_Moresby",
         "Pacific/Enderbury", "Pacific/Kanton",
+        "Pacific/Funafuti", "Pacific/Tarawa",
         "Pacific/Johnston", "Pacific/Honolulu",
+        "Pacific/Majuro", "Pacific/Tarawa",
         "Pacific/Midway", "Pacific/Pago_Pago",
-        "Pacific/Ponape", "Pacific/Pohnpei",
+        "Pacific/Pohnpei", "Pacific/Guadalcanal",
+        "Pacific/Ponape", "Pacific/Guadalcanal",
         "Pacific/Saipan", "Pacific/Guam",
         "Pacific/Samoa", "Pacific/Pago_Pago",
-        "Pacific/Truk", "Pacific/Chuuk",
-        "Pacific/Yap", "Pacific/Chuuk",
+        "Pacific/Truk", "Pacific/Port_Moresby",
+        "Pacific/Wake", "Pacific/Tarawa",
+        "Pacific/Wallis", "Pacific/Tarawa",
+        "Pacific/Yap", "Pacific/Port_Moresby",
         "Poland", "Europe/Warsaw",
         "Portugal", "Europe/Lisbon",
         "ROC", "Asia/Taipei",
