@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1433,6 +1433,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Tule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "timezone.excity.America/Indiana/Petersburg", "Pitersberg, Indiana" },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Vinnipeg" },
@@ -1939,8 +1940,8 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kvajaleyn" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lissabon" },
             { "timezone.excity.Pacific/Gambier", "Gambye oroli" },
